@@ -26,9 +26,11 @@ class Post(models.Model):
     slug = models.SlugField()
     text = models.TextField(_('Text'))
     tags = TagField()
+    image = models.ImageField(_('Image'), upload_to='images/posts', blank=True)
     hits = models.IntegerField(_('Hits'), blank=True, default=1)
     creation_date = models.DateTimeField(_('Creation date'))
     user = models.ForeignKey(User, related_name="post_from")
+    highlighted =  models.BooleanField(_('Highlighted'), blank=True)
     status =  models.BooleanField(_('Status'), default=True)
     thread_id = models.CharField(max_length=32, blank=True) # DISQUS
 
@@ -74,6 +76,9 @@ class Comments(models.Model):
     author_url = models.CharField(max_length=200)
     date = models.DateTimeField()
 
+    def __unicode__(self):
+        return "%s - %s" % (self.author_name, self.body)
+
     class Meta:
         verbose_name = _('Comment')
         verbose_name_plural = _('Comments')
