@@ -19,7 +19,8 @@ urlpatterns = patterns('',
     url(r'^feed/$',                                AllFeed(), {}, 'app_blog-feed'),
     url(r'^feed.rss$',                             AllFeed(), {}, 'app_blog-feed2'),
     # 1 day cache
-    url(r'^ajax/testing/$',                        cache_page(60 * 24)(AJAXArchive.as_view()), {}, 'app_blog-ajaxarchive'),
+    url(r'^ajax/testing/$',                        (AJAXArchive.as_view()), {}, 'app_blog-ajaxarchive'),
+    url(r'^archive/$',                             (AJAXArchive.as_view()), {}, 'app_blog-archive'),
 )
 
 
