@@ -37,7 +37,7 @@ class BlogIndexView(MetaSidebar, ListView):
         MetaSidebar.__init__(self)
 
     def get_queryset(self):
-        print datetime.datetime.now()
+        #print datetime.datetime.now()
         return mymodels.Post.objects.all().filter(status=1,
             creation_date__lte=datetime.datetime.now()).order_by('-creation_date')
 
@@ -66,14 +66,14 @@ class PostDetailView(MetaSidebar, DetailView):
         if conf.DISQUS_SYNC:
             if not self.obj.thread_id:
                 try:
-                    print 'link:http://'+current_site.domain+current_url
+                    #print 'link:http://'+current_site.domain+current_url
                     api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
                     dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://'+current_site.domain+current_url)
                     self.obj.thread_id = dq_response['id']
                 except:
                     pass
                 try:
-                    print 'link:http://www.'+current_site.domain+current_url
+                    #print 'link:http://www.'+current_site.domain+current_url
                     api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
                     dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://www.'+current_site.domain+current_url)
                     self.obj.thread_id = dq_response['id']
